# Generated by Django 2.1.7 on 2019-02-22 03:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0009_scmsteprun'),
    ]

    operations = [
        migrations.RenameField(
            model_name='scmservice',
            old_name='type',
            new_name='scm_service_type',
        ),
    ]
